@@ -279,7 +279,7 @@ class ModbusClient:
         # frame with bits value -> bits[] list
         f_bits = bytearray(f_body[1:])
         # check rx_byte_count: match nb of bits request and check buffer size
-        if not ((rx_byte_count == int((bit_nb+7)/8)) or
+        if not ((rx_byte_count == int((bit_nb+7)/8)) and
                 (rx_byte_count == len(f_bits))):
             self.__last_error = const.MB_RECV_ERR
             self.__debug_msg("read_coils(): rx byte count mismatch")
@@ -337,7 +337,7 @@ class ModbusClient:
         # frame with bits value -> bits[] list
         f_bits = bytearray(f_body[1:])
         # check rx_byte_count: match nb of bits request and check buffer size
-        if not ((rx_byte_count == int((bit_nb+7)/8)) or
+        if not ((rx_byte_count == int((bit_nb+7)/8)) and
                 (rx_byte_count == len(f_bits))):
             self.__last_error = const.MB_RECV_ERR
             self.__debug_msg("read_discrete_inputs(): rx byte count mismatch")
@@ -396,7 +396,7 @@ class ModbusClient:
         # frame with regs value
         f_regs = f_body[1:]
         # check rx_byte_count: match nb of bits request and check buffer size
-        if not ((rx_byte_count == 2*reg_nb) or
+        if not ((rx_byte_count == 2*reg_nb) and
                 (rx_byte_count == len(f_regs))):
             self.__last_error = const.MB_RECV_ERR
             self.__debug_msg("read_holding_registers(): rx byte count mismatch")
@@ -454,7 +454,7 @@ class ModbusClient:
         # frame with regs value
         f_regs = f_body[1:]
         # check rx_byte_count: match nb of bits request and check buffer size
-        if not ((rx_byte_count == 2*reg_nb) or
+        if not ((rx_byte_count == 2*reg_nb) and
                 (rx_byte_count == len(f_regs))):
             self.__last_error = const.MB_RECV_ERR
             self.__debug_msg("read_input_registers(): rx byte count mismatch")
